@@ -15,7 +15,7 @@ import hashlib
 import logging
 from jinja2 import Environment, FileSystemLoader
 import liquidluck
-from liquidluck.utils import import_object, to_unicode, utf8
+from liquidluck.utils import import_object, to_unicode, to_bytes, utf8
 
 # blog settings
 from liquidluck.options import settings
@@ -31,10 +31,13 @@ class BaseWriter(object):
         raise NotImplementedError
 
     def run(self):
-        try:
+        if g.detail_logging:
             self.start()
-        except Exception as e:
-            logging.error(e)
+        else:
+            try:
+                self.start()
+            except Exception as e:
+                logging.error(e)
 
         name = self.__class__.__name__
         logging.info('%s Finished' % name)
@@ -231,6 +234,10 @@ def get_post_slug(post, slug_format):
 
         if not value:
             return ''
+
+        if isinstance(value, int) and value < 10:
+            #: fix on month and date value
+            value = '0%d' % value
         return to_unicode(value)
 
     slug = regex.sub(replace, slug_format)
@@ -322,7 +329,7 @@ def static_url(base):
 
         with open(abspath) as f:
             content = f.read()
-            hsh = hashlib.md5(content.encode('utf-8')).hexdigest()
+            hsh = hashlib.md5(to_bytes(content)).hexdigest()
             _Cache[path] = hsh
             return hsh
 
